Temperature

Struct Temperature 

pub struct Temperature;
A temperature.

Implementations

Source

impl Temperature

pub const fn kelvin(value: TensorRank0) -> Quantity<Temperature>

A quantity of kelvin.

Source

impl Temperature

pub const fn celsius(value: TensorRank0) -> Quantity<Temperature>

A quantity of degrees celsius.

A celsius is a kelvin offset rather than scaled, so this names a temperature and not a difference between two. A difference is the same number of either, and is the kelvin it already is.

pub const fn fahrenheit(value: TensorRank0) -> Quantity<Temperature>

A quantity of degrees fahrenheit.

Offset as well as scaled, so the same caution applies as for celsius.