pub struct Temperature;Expand description
A temperature.
Implementations
Sourceimpl Temperature
impl Temperature
Sourcepub const fn kelvin(value: TensorRank0) -> Quantity<Temperature>
pub const fn kelvin(value: TensorRank0) -> Quantity<Temperature>
A quantity of kelvin.
Sourceimpl Temperature
impl Temperature
Sourcepub const fn celsius(value: TensorRank0) -> Quantity<Temperature>
pub const fn celsius(value: TensorRank0) -> Quantity<Temperature>
A quantity of degrees celsius.
A celsius is a kelvin offset rather than scaled, so this names a
temperature and not a difference between two. A difference is the same
number of either, and is the kelvin it already is.
Sourcepub const fn fahrenheit(value: TensorRank0) -> Quantity<Temperature>
pub const fn fahrenheit(value: TensorRank0) -> Quantity<Temperature>
A quantity of degrees fahrenheit.
Offset as well as scaled, so the same caution applies as for
celsius.