pub trait UnitInv {
type Output;
}Expand description
The unit obtained by inverting.
Left unimplemented for units whose inverse names no quantity, so that inverting such a tensor fails to compile.
pub trait UnitInv {
type Output;
}The unit obtained by inverting.
Left unimplemented for units whose inverse names no quantity, so that inverting such a tensor fails to compile.